@@ -141,13 +141,13 @@ method.name<-"Estimating Box-Cox transformation parameter via maximum likelihood
            
 
       par(mfrow=c(2,2))
-      hist(data, xlab = dname, prob=TRUE, main = paste("Histogram of", dname))
+      hist(data, xlab = "Data", prob=TRUE, main = paste("Histogram of data"))
       lines(density(data))
-      hist(data.transformed, xlab = paste("Transformed", dname), prob=TRUE, main = paste("Histogram of tf", dname))
+      hist(data.transformed, xlab = paste("Transformed data"), prob=TRUE, main = paste("Histogram of tf data"))
       lines(density(data.transformed))
-      qqnorm(data, main = paste("Q-Q plot of", dname))
+      qqnorm(data, main = paste("Q-Q plot of data"))
       qqline(data)
-      qqnorm(data.transformed, main = paste("Q-Q plot of tf", dname))
+      qqnorm(data.transformed, main = paste("Q-Q plot of tf data"))
       qqline(data.transformed)
            
            
